Documentation
¶
Index ¶
- func DisableFlagsInUseLine(cmd *cobra.Command)
- func ExactArgs(number int) cobra.PositionalArgs
- func FlagErrorFunc(cmd *cobra.Command, err error) error
- func NoArgs(cmd *cobra.Command, args []string) error
- func RequiresMaxArgs(maxArgs int) cobra.PositionalArgs
- func RequiresMinArgs(minArgs int) cobra.PositionalArgs
- func RequiresRangeArgs(minArgs int, maxArgs int) cobra.PositionalArgs
- func SetupRootCommand(rootCmd *cobra.Command) (opts *cliflags.ClientOptions, helpCmd *cobra.Command)
- func VisitAll(root *cobra.Command, fn func(*cobra.Command))
- type StatusError
- type TopLevelCommand
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DisableFlagsInUseLine ¶
DisableFlagsInUseLine sets the DisableFlagsInUseLine flag on all commands within the tree rooted at cmd.
func ExactArgs ¶
func ExactArgs(number int) cobra.PositionalArgs
ExactArgs returns an error if there is not the exact number of args
func FlagErrorFunc ¶
FlagErrorFunc prints an error message which matches the format of the wpm/cli/cli error messages
func RequiresMaxArgs ¶
func RequiresMaxArgs(maxArgs int) cobra.PositionalArgs
RequiresMaxArgs returns an error if there is not at most max args
func RequiresMinArgs ¶
func RequiresMinArgs(minArgs int) cobra.PositionalArgs
RequiresMinArgs returns an error if there is not at least min args
func RequiresRangeArgs ¶
func RequiresRangeArgs(minArgs int, maxArgs int) cobra.PositionalArgs
RequiresRangeArgs returns an error if there is not at least min args and at most max args
func SetupRootCommand ¶
func SetupRootCommand(rootCmd *cobra.Command) (opts *cliflags.ClientOptions, helpCmd *cobra.Command)
SetupRootCommand sets default usage, help, and error handling for the root command.
Types ¶
type StatusError ¶
StatusError reports an unsuccessful exit by a command.
func (StatusError) Error ¶
func (e StatusError) Error() string
Error formats the error for printing. If a custom Status is provided, it is returned as-is, otherwise it generates a generic error-message based on the StatusCode.
func (StatusError) Unwrap ¶
func (e StatusError) Unwrap() error
type TopLevelCommand ¶
type TopLevelCommand struct {
// contains filtered or unexported fields
}
TopLevelCommand encapsulates a top-level cobra command and global flag handling logic necessary for plugins.
func NewTopLevelCommand ¶
func NewTopLevelCommand(cmd *cobra.Command, wpmCli *command.WpmCli, opts *cliflags.ClientOptions, flags *pflag.FlagSet) *TopLevelCommand
NewTopLevelCommand returns a new TopLevelCommand object
func (*TopLevelCommand) HandleGlobalFlags ¶
func (tcmd *TopLevelCommand) HandleGlobalFlags() (*cobra.Command, []string, error)
HandleGlobalFlags takes care of parsing global flags defined on the command, it returns the underlying cobra command and the args it will be called with (or an error).
On success the caller is responsible for calling Initialize() before calling `Execute` on the returned command.
func (*TopLevelCommand) Initialize ¶
func (tcmd *TopLevelCommand) Initialize(ops ...command.CLIOption) error
Initialize finalises global option parsing and initializes the wpm client.